@@ -28,6 +28,7 @@
 
 #include <KIO/Global>
 #include <KLocalizedString>
+#include <KIconLoader>
 
 #include <QDBusConnection>
 #include <QMimeData>
@@ -308,7 +309,8 @@ bool ArchiveModel::dropMimeData(const QMimeData *data, Qt::DropAction action, in
     }
 
     QStringList paths;
-    foreach(const QUrl &url, data->urls()) {
+    const auto urls = data->urls();
+    for (const QUrl &url : urls) {
         paths << url.toLocalFile();
     }
 
@@ -381,7 +383,7 @@ Archive::Entry *ArchiveModel::parentFor(const Archive::Entry *entry, InsertBehav
 
     Archive::Entry *parent = m_rootEntry.data();
 
-    foreach(const QString &piece, pieces) {
+    for (const QString &piece : qAsConst(pieces)) {
         Archive::Entry *entry = parent->find(piece);
         if (!entry) {
             // Directory entry will be traversed later (that happens for some archive formats, 7z for instance).
@@ -749,7 +751,7 @@ bool ArchiveModel::conflictingEntries(QList<const Archive::Entry*> &conflictingE
     const Archive::Entry *lastDirEntry = destination;
     QString skippedDirPath;
 
-    foreach (const QString &entry, entries) {
+    for (const QString &entry : entries) {
         if (skippedDirPath.count() > 0 && entry.startsWith(skippedDirPath)) {
             continue;
         } else {
@@ -793,7 +795,7 @@ bool ArchiveModel::conflictingEntries(QList<const Archive::Entry*> &conflictingE
 bool ArchiveModel::hasDuplicatedEntries(const QStringList &entries)
 {
     QStringList tempList;
-    foreach (const QString &entry, entries) {
+    for (const QString &entry : entries) {
         if (tempList.contains(entry)) {
             return true;
         }
@@ -805,7 +807,7 @@ bool ArchiveModel::hasDuplicatedEntries(const QStringList &entries)
 QMap<QString, Archive::Entry*> ArchiveModel::entryMap(const QVector<Archive::Entry*> &entries)
 {
     QMap<QString, Archive::Entry*> map;
-    foreach (Archive::Entry *entry, entries) {
+    for (Archive::Entry *entry : entries) {
         map.insert(entry->fullPath(), entry);
     }
     return map;
@@ -842,7 +844,7 @@ void ArchiveModel::slotCleanupEmptyDirs()
         }
     }
 
-    foreach(const QPersistentModelIndex& node, nodesToDelete) {
+    for (const QPersistentModelIndex& node : qAsConst(nodesToDelete)) {
         Archive::Entry *rawEntry = static_cast<Archive::Entry*>(node.internalPointer());
         qCDebug(ARK) << "Delete with parent entries " << rawEntry->getParent()->entries() << " and row " << rawEntry->row();
         beginRemoveRows(parent(node), rawEntry->row(), rawEntry->row());
@@ -875,7 +877,8 @@ void ArchiveModel::countEntriesAndSize()
 
 void ArchiveModel::traverseAndCountDirNode(Archive::Entry *dir)
 {
-    foreach(Archive::Entry *entry, dir->entries()) {
+    const auto entries = dir->entries();
+    for (Archive::Entry *entry : entries) {
         if (entry->isDir()) {
             traverseAndCountDirNode(entry);
             m_numberOfFolders++;
