@@ -69,13 +69,13 @@ bool ReadWriteLibarchivePlugin::addFiles(const QVector<Archive::Entry*> &files,
 
     // First write the new files.
     qCDebug(ARK) << "Writing new entries";
-    uint no_entries = 0;
+    uint addedEntries = 0;
     // Recreate destination directory structure.
     const QString destinationPath = (destination == nullptr)
                                     ? QString()
                                     : destination->fullPath();
 
-    foreach(Archive::Entry *selectedFile, files) {
+    for (Archive::Entry *selectedFile : files) {
         if (QThread::currentThread()->isInterruptionRequested()) {
             break;
         }
@@ -84,8 +84,8 @@ bool ReadWriteLibarchivePlugin::addFiles(const QVector<Archive::Entry*> &files,
             finish(false);
             return false;
         }
-        no_entries++;
-        emit progress(float(no_entries)/float(totalCount));
+        addedEntries++;
+        emit progress(float(addedEntries)/float(totalCount));
 
         // For directories, write all subfiles/folders.
         const QString &fullPath = selectedFile->fullPath();
@@ -113,21 +113,21 @@ bool ReadWriteLibarchivePlugin::addFiles(const QVector<Archive::Entry*> &files,
                     finish(false);
                     return false;
                 }
-                no_entries++;
-                emit progress(float(no_entries)/float(totalCount));
+                addedEntries++;
+                emit progress(float(addedEntries)/float(totalCount));
             }
         }
     }
-    qCDebug(ARK) << "Added" << no_entries << "new entries to archive";
+    qCDebug(ARK) << "Added" << addedEntries << "new entries to archive";
 
     bool isSuccessful = true;
     // If we have old archive entries.
     if (!creatingNewFile) {
         qCDebug(ARK) << "Copying any old entries";
         m_filesPaths = m_writtenFiles;
-        isSuccessful = processOldEntries(no_entries, Add, totalCount);
+        isSuccessful = processOldEntries(addedEntries, Add, totalCount);
         if (isSuccessful) {
-            qCDebug(ARK) << "Added" << no_entries << "old entries to archive";
+            qCDebug(ARK) << "Added" << addedEntries << "old entries to archive";
         } else {
             qCDebug(ARK) << "Adding entries failed";
         }
@@ -152,13 +152,13 @@ bool ReadWriteLibarchivePlugin::moveFiles(const QVector<Archive::Entry*> &files,
     }
 
     // Copy old elements from previous archive to new archive.
-    uint no_entries = 0;
+    uint movedEntries = 0;
     m_filesPaths = entryFullPaths(files);
     m_entriesWithoutChildren = entriesWithoutChildren(files).count();
     m_destination = destination;
-    const bool isSuccessful = processOldEntries(no_entries, Move, m_numberOfEntries);
+    const bool isSuccessful = processOldEntries(movedEntries, Move, m_numberOfEntries);
     if (isSuccessful) {
-        qCDebug(ARK) << "Moved" << no_entries << "entries within archive";
+        qCDebug(ARK) << "Moved" << movedEntries << "entries within archive";
     } else {
         qCDebug(ARK) << "Moving entries failed";
     }
@@ -182,12 +182,12 @@ bool ReadWriteLibarchivePlugin::copyFiles(const QVector<Archive::Entry*> &files,
     }
 
     // Copy old elements from previous archive to new archive.
-    uint no_entries = 0;
+    uint copiedEntries = 0;
     m_filesPaths = entryFullPaths(files);
     m_destination = destination;
-    const bool isSuccessful = processOldEntries(no_entries, Copy, m_numberOfEntries);
+    const bool isSuccessful = processOldEntries(copiedEntries, Copy, m_numberOfEntries);
     if (isSuccessful) {
-        qCDebug(ARK) << "Copied" << no_entries << "entries within archive";
+        qCDebug(ARK) << "Copied" << copiedEntries << "entries within archive";
     } else {
         qCDebug(ARK) << "Copying entries failed";
     }
@@ -209,11 +209,11 @@ bool ReadWriteLibarchivePlugin::deleteFiles(const QVector<Archive::Entry*> &file
     }
 
     // Copy old elements from previous archive to new archive.
-    uint no_entries = 0;
+    uint deletedEntries = 0;
     m_filesPaths = entryFullPaths(files);
-    const bool isSuccessful = processOldEntries(no_entries, Delete, m_numberOfEntries);
+    const bool isSuccessful = processOldEntries(deletedEntries, Delete, m_numberOfEntries);
     if (isSuccessful) {
-        qCDebug(ARK) << "Removed" << no_entries << "entries from archive";
+        qCDebug(ARK) << "Removed" << deletedEntries << "entries from archive";
     } else {
         qCDebug(ARK) << "Removing entries failed";
     }
@@ -224,10 +224,6 @@ bool ReadWriteLibarchivePlugin::deleteFiles(const QVector<Archive::Entry*> &file
 
 bool ReadWriteLibarchivePlugin::initializeWriter(const bool creatingNewFile, const CompressionOptions &options)
 {
-    // |tempFile| needs to be created before |arch_writer| so that when we go
-    // out of scope in a `return false' case ArchiveWriteCustomDeleter is
-    // called before destructor of QSaveFile (ie. we call archive_write_close()
-    // before close()'ing the file descriptor).
     m_tempFile.setFileName(filename());
     if (!m_tempFile.open(QIODevice::WriteOnly | QIODevice::Unbuffered)) {
         emit error(i18nc("@info", "Failed to create a temporary file for writing data."));
@@ -389,16 +385,20 @@ bool ReadWriteLibarchivePlugin::initializeNewFileWriterFilters(const Compression
 void ReadWriteLibarchivePlugin::finish(const bool isSuccessful)
 {
     if (!isSuccessful || QThread::currentThread()->isInterruptionRequested()) {
+        archive_write_fail(m_archiveWriter.data());
         m_tempFile.cancelWriting();
+    } else {
+        // archive_write_close() needs to be called before calling QSaveFile::commit(),
+        // otherwise the latter will close() the file descriptor m_archiveWriter is still working on.
+        // TODO: We need to abstract this code better so that we only deal with one
+        // object that manages both QSaveFile and ArchiveWriter.
+        archive_write_close(m_archiveWriter.data());
+        m_tempFile.commit();
     }
-    archive_write_close(m_archiveWriter.data());
-    m_tempFile.commit();
 }
 
 bool ReadWriteLibarchivePlugin::processOldEntries(uint &entriesCounter, OperationMode mode, uint totalCount)
 {
-    struct archive_entry *entry;
-
     const uint newEntries = entriesCounter;
     entriesCounter = 0;
     uint iteratedEntries = 0;
@@ -415,6 +415,7 @@ bool ReadWriteLibarchivePlugin::processOldEntries(uint &entriesCounter, Operatio
         }
     }
 
+    struct archive_entry *entry;
     while (!QThread::currentThread()->isInterruptionRequested() && archive_read_next_header(m_archiveReader.data(), &entry) == ARCHIVE_OK) {
 
         const QString file = QFile::decodeName(archive_entry_pathname(entry));
@@ -476,7 +477,7 @@ bool ReadWriteLibarchivePlugin::processOldEntries(uint &entriesCounter, Operatio
         emit progress(float(newEntries + entriesCounter + iteratedEntries)/float(totalCount));
     }
 
-    return true;
+    return !QThread::currentThread()->isInterruptionRequested();
 }
 
 bool ReadWriteLibarchivePlugin::writeEntry(struct archive_entry *entry)
@@ -507,7 +508,6 @@ bool ReadWriteLibarchivePlugin::writeEntry(struct archive_entry *entry)
 //       such as an fd to archive_read_disk_entry_from_file()
 bool ReadWriteLibarchivePlugin::writeFile(const QString &relativeName, const QString &destination)
 {
-    int header_response;
     const QString absoluteFilename = QFileInfo(relativeName).absoluteFilePath();
     const QString destinationFilename = destination + relativeName;
 
@@ -524,12 +524,13 @@ bool ReadWriteLibarchivePlugin::writeFile(const QString &relativeName, const QSt
     archive_entry_copy_sourcepath(entry, QFile::encodeName(absoluteFilename).constData());
     archive_read_disk_entry_from_file(m_archiveReadDisk.data(), entry, -1, &st);
 
-    if ((header_response = archive_write_header(m_archiveWriter.data(), entry)) == ARCHIVE_OK) {
+    const auto returnCode = archive_write_header(m_archiveWriter.data(), entry);
+    if (returnCode == ARCHIVE_OK) {
         // If the whole archive is extracted and the total filesize is
         // available, we use partial progress.
         copyData(absoluteFilename, m_archiveWriter.data(), false);
     } else {
-        qCCritical(ARK) << "Writing header failed with error code " << header_response;
+        qCCritical(ARK) << "Writing header failed with error code " << returnCode;
         qCCritical(ARK) << "Error while writing..." << archive_error_string(m_archiveWriter.data()) << "(error no =" << archive_errno(m_archiveWriter.data()) << ')';
 
         emit error(i18nc("@info Error in a message box",
@@ -540,6 +541,11 @@ bool ReadWriteLibarchivePlugin::writeFile(const QString &relativeName, const QSt
         return false;
     }
 
+    if (QThread::currentThread()->isInterruptionRequested()) {
+        archive_entry_free(entry);
+        return false;
+    }
+
     m_writtenFiles.push_back(destinationFilename);
 
     emitEntryFromArchiveEntry(entry);
